@@ -24,7 +24,11 @@ while 1:
 
 	mtime = 0
 	for s in split[1:]:
-	    key, value = string.split(s, ':')
+	    list = string.split(s, ':')
+	    try:
+		key, value = list
+	    except:
+		continue
 	    if key == 'ID' and len(value) > 2:
 		md5 = value
 		subdir = dirname + '/' + value[0:2]
